// Copyright (C) 2009 - Digiteo - Michael Baudin
// Copyright (C) INRIA - Farid BELAHCENE
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

//
// number_check --
//   Check that the input integer can be managed correctly.
//   If not, generates an error.
//   Performs the following checkings :
//   * checks that this is a real type variable
//   * check that it is in the interval [-2^52,2^52]
//   * check that there is no fraction part in the value (floor(n) and n 
//     should be equal)
//   * check that n is a scalar (its size is 1)
//
function number_check ( n )
  if ( type(n)<>1 ) then
    error(msprintf(gettext("%s: Wrong type for integer %s: A real expected.\n"),"number_check" , string(n) ));
  end
  number_checkrange ( n )
  if ( n - floor(n) <> 0 )
        error(msprintf(gettext ( "%s: Wrong value for integer %s: This is not an integer.") , "number_check" , string(n) ))
  end
  if ( prod(size(n,"*"))<>1 ) then
    error(msprintf(gettext("%s: Wrong size for input argument [%s]: A scalar is expected but current size is %d x %d.\n"),"number_check" , strcat ( string(s), " ") , size(n,1) , size(n,2)));
  end	
endfunction

