// Copyright (C) 2009 - Digiteo - Michael Baudin

// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

//
// number_extendedeuclid --
//   Returns d, x and y such that d is the GCD of a and b and 
//   d = xa + yb
// Reference
//   "Introduction to algorithms", Cormen, Leiserson, Rivest, Stein, 2nd edition
//   
function [ d , x , y ] = number_extendedeuclid ( a , b )
  number_check ( a )
  number_checkpositive ( "a" , a )
  number_check ( b )
  number_checkpositive ( "b" , b )
  if ( b == 0 ) then
    d = a
    x = 1
    y = 0
    return
  end
  [ dp , xp , yp ] = number_extendedeuclid ( b , pmodulo ( a , b ) )
  d = dp
  x = yp
  y = xp - floor ( a / b ) * yp
endfunction

