// Copyright (C) 2009 - Digiteo - Michael Baudin

// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

//
// number_pseudoprime --
//   Returns %f if the number is composite.
//   Returns %t if the number is a base-a pseudo-prime, 
//   in which case the number n may be either prime or pseudo-prime.
//   A base-a pseudo prime is so that a^(n-1) = 1 (mod n).
// Arguments
//   n : the number to test for primality
//   a : the base (default 2)
// Calling sequences
//   isprime = number_pseudoprime ( n )
//   isprime = number_pseudoprime ( n , a )
//   
function isprime = number_pseudoprime ( varargin )
  [lhs,rhs]=argn();
  if ( ( rhs <> 1 ) & ( rhs <> 2 ) ) then
    errmsg = msprintf(gettext("%s: Unexpected number of input arguments : %d provided while %d or %d are expected."), "number_pseudoprime" , rhs , 1 , 2 );
    error(errmsg)
  end
  select rhs
  case 1 then
    n = varargin ( 1 )
    a = 2
  case 2 then
    n = varargin ( 1 )
    a = varargin ( 2 )
  end
  number_check ( a )
  number_check ( n )
  number_checkpositive ( "a" , a )
  number_checkpositive ( "n" , n )
  b = number_powermod ( a , n - 1 , n )
  if ( b <> 1 ) then
    isprime = %f 
    // Definitely
  else
    isprime = %t 
    // We hope !
  end
endfunction

