// Copyright (C) 2009 - Digiteo - Michael Baudin

// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

//
// number_solvelinmod --
//   Returns the row vector of all x such that ax = b (mod n).
// Reference
//   "Introduction to algorithms", Cormen, Leiserson, Rivest, Stein, 2nd edition
//   
function x = number_solvelinmod ( a , b , n )
  number_check ( a )
  number_checkpositive ( "a" , a )
  number_check ( b )
  number_checkpositive ( "b" , b )
  number_check ( n )
  number_checkpositive ( "n" , n )
  x = []
  [ d , xp , yp ] = number_extendedeuclid ( a , n )
  isdivisor = number_isdivisor ( d , b )
  if ( isdivisor ) then
    x0 = pmodulo ( xp * ( b / d ) , n )
    for i = 0 : d - 1
      x ( 1 , $ + 1 ) = pmodulo ( x0 + i * ( n / d ) , n )
    end
  end
endfunction

